@@ -3,17 +3,16 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4002';
+our $VERSION = '0.4003';
 
+use strictures 2;
 use Data::Dumper::Compact qw(ddc);
 use List::Util qw(sum0);
 use Math::Bezier ();
 use MIDI::Util qw(dura_size reverse_dump set_chan_patch set_time_signature);
+use Moo;
 use Music::Duration ();
 use Music::RhythmSet::Util qw(upsize);
-
-use Moo;
-use strictures 2;
 use namespace::clean;
 
 use constant TICKS => 96; # Per quarter note
@@ -43,7 +42,7 @@ has kit       => ( is => 'ro', default => sub { 0 } );
 has reverb    => ( is => 'ro', default => sub { 15 } );
 has channel   => ( is => 'ro', default => sub { 9 } );
 has volume    => ( is => 'ro', default => sub { 100 } );
-has bpm       => ( is => 'ro', default => sub { 120 } );
+has bpm       => ( is => 'rw', default => sub { 120 } );
 has file      => ( is => 'ro', default => sub { 'MIDI-Drummer.mid' } );
 has bars      => ( is => 'ro', default => sub { 4 } );
 has score     => ( is => 'ro', default => sub { MIDI::Simple->new_score } );
@@ -538,6 +537,13 @@ sub set_time_sig {
 }
 
 
+sub set_bpm {
+    my ($self, $bpm) = @_;
+    $self->bpm($bpm);
+    $self->score->set_tempo( int( 60_000_000 / $self->bpm ) );
+}
+
+
 sub sync {
     my $self = shift;
     $self->score->synch(@_);
@@ -578,7 +584,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4002
+version 0.4003
 
 =head1 SYNOPSIS
 
@@ -1008,6 +1014,10 @@ If a ratio argument is given, set the B<signature> object attribute to
 it.  If the 2nd argument flag is C<0>, the B<beats> and B<divisions>
 are B<not> reset.
 
+=head2 set_bpm
+
+Reset the beats per minute.
+
 =head2 sync
 
   $d->sync(@code_refs);
